@@ -1698,14 +1698,26 @@ _SC_checkResolverReachability(SCDynamicStoreRef		*storeP,
 			}
 		} else if (default_resolver->domain != NULL) {
 			char	*dp;
-			int	domain_parts	= 1;
+			int	domain_parts	= 0;
 
+			// count domain parts
 			for (dp = default_resolver->domain; *dp != '\0'; dp++) {
 				if (*dp == '.') {
 					domain_parts++;
 				}
 			}
 
+			// remove trailing dots
+			for (dp--; (dp >= default_resolver->domain) && (*dp == '.'); dp--) {
+				*dp = '\0';
+				domain_parts--;
+			}
+
+			if (dp >= default_resolver->domain) {
+				// dots are separators, bump # of components
+				domain_parts++;
+			}
+
 			dp = default_resolver->domain;
 			for (i = LOCALDOMAINPARTS; !found && (i <= domain_parts); i++) {
 				int	ret;
