@@ -54,6 +54,20 @@ _IOMasterPort				(
 					);
 #define IOMasterPort _IOMasterPort
 
+boolean_t
+_IOObjectConformsTo			(
+					io_object_t		object,
+					const io_name_t		className
+					);
+#define IOObjectConformsTo _IOObjectConformsTo
+
+boolean_t
+_IOObjectGetClass			(
+					io_object_t		object,
+					io_name_t		className
+					);
+#define IOObjectGetClass _IOObjectGetClass
+
 kern_return_t
 _IOObjectRelease			(
 					io_object_t		object
@@ -78,6 +92,22 @@ _IORegistryEntryCreateCFProperties	(
 					);
 #define IORegistryEntryCreateCFProperties _IORegistryEntryCreateCFProperties
 
+kern_return_t
+_IORegistryEntryCreateIterator		(
+					io_registry_entry_t	entry,
+					const io_name_t		plane,
+					IOOptionBits		options,
+					io_iterator_t		*iterator
+					);
+#define IORegistryEntryCreateIterator _IORegistryEntryCreateIterator
+
+kern_return_t
+_IORegistryEntryGetName			(
+					io_registry_entry_t	entry,
+					io_name_t               name
+					);
+#define	IORegistryEntryGetName _IORegistryEntryGetName
+
 kern_return_t
 _IORegistryEntryGetParentEntry		(
 					io_registry_entry_t	entry,
@@ -94,6 +124,16 @@ _IORegistryEntryGetPath			(
 					);
 #define IORegistryEntryGetPath _IORegistryEntryGetPath
 
+CFTypeRef
+_IORegistryEntrySearchCFProperty	(
+					io_registry_entry_t     entry,
+					const io_name_t         plane,
+					CFStringRef             key,
+					CFAllocatorRef          allocator,
+					IOOptionBits            options
+					);
+#define IORegistryEntrySearchCFProperty _IORegistryEntrySearchCFProperty
+
 kern_return_t
 _IOServiceGetMatchingServices		(
 					mach_port_t		masterPort,
