@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2003 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 2000-2004 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
@@ -44,7 +44,9 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
+#include <dnsinfo.h>
 
+__private_extern__
 void
 do_checkReachability(int argc, char **argv)
 {
@@ -161,6 +163,90 @@ do_checkReachability(int argc, char **argv)
 }
 
 
+__private_extern__
+void
+do_showDNSConfiguration(int argc, char **argv)
+{
+	dns_config_t	*dns_config;
+
+	dns_config = dns_configuration_copy();
+	if (dns_config) {
+		int	n;
+
+		SCPrint(TRUE, stdout, CFSTR("DNS configuration\n"));
+
+		for (n = 0; n < dns_config->n_resolver; n++) {
+			int		i;
+			dns_resolver_t	*resolver	= dns_config->resolver[n];
+
+			SCPrint(TRUE, stdout, CFSTR("\nresolver #%d\n"), n + 1);
+
+			if (resolver->domain != NULL) {
+				SCPrint(TRUE, stdout, CFSTR("  domain : %s\n"), resolver->domain);
+			}
+
+			for (i = 0; i < resolver->n_search; i++) {
+				SCPrint(TRUE, stdout, CFSTR("  search domain[%d] : %s\n"), i, resolver->search[i]);
+			}
+
+			for (i = 0; i < resolver->n_nameserver; i++) {
+				char	buf[128];
+
+				_SC_sockaddr_to_string(resolver->nameserver[i], buf, sizeof(buf));
+				SCPrint(TRUE, stdout, CFSTR("  nameserver[%d] : %s\n"), i, buf);
+			}
+
+			for (i = 0; i < resolver->n_sortaddr; i++) {
+				SCPrint(TRUE, stdout, CFSTR("  sortaddr[%d] : %s/%s\n"),
+					i,
+					inet_ntoa(resolver->sortaddr[i]->address),
+					inet_ntoa(resolver->sortaddr[i]->mask));
+			}
+
+			if (resolver->options != NULL) {
+				SCPrint(TRUE, stdout, CFSTR("  options : %s\n"), resolver->options);
+			}
+
+			if (resolver->port != 0) {
+				SCPrint(TRUE, stdout, CFSTR("  port    : %hd\n"), resolver->port);
+			}
+
+			if (resolver->timeout != 0) {
+				SCPrint(TRUE, stdout, CFSTR("  timeout : %d\n"), resolver->timeout);
+			}
+
+			if (resolver->search_order != 0) {
+				SCPrint(TRUE, stdout, CFSTR("  order   : %d\n"), resolver->search_order);
+			}
+		}
+
+		dns_configuration_free(dns_config);
+	} else {
+		SCPrint(TRUE, stdout, CFSTR("No DNS configuration available\n"));
+	}
+
+	exit(0);
+}
+
+
+__private_extern__
+void
+do_showProxyConfiguration(int argc, char **argv)
+{
+	CFDictionaryRef proxies;
+
+	proxies = SCDynamicStoreCopyProxies(NULL);
+	if (proxies != NULL) {
+		SCPrint(TRUE, stdout, CFSTR("%@\n"), proxies);
+	} else {
+		SCPrint(TRUE, stdout, CFSTR("No proxy configuration available\n"));
+	}
+
+	exit(0);
+}
+
+
+__private_extern__
 void
 do_snapshot(int argc, char **argv)
 {
@@ -185,6 +271,7 @@ waitTimeout(int sigraised)
 }
 
 
+__private_extern__
 void
 do_wait(char *waitKey, int timeout)
 {
@@ -193,14 +280,14 @@ do_wait(char *waitKey, int timeout)
 	CFMutableArrayRef	keys;
 
 	store = SCDynamicStoreCreate(NULL, CFSTR("scutil (wait)"), waitKeyFound, NULL);
-	if (!store) {
+	if (store == NULL) {
 		SCPrint(TRUE, stderr,
 			CFSTR("SCDynamicStoreCreate() failed: %s\n"), SCErrorString(SCError()));
 		exit(1);
 	}
 
 	keys = CFArrayCreateMutable(NULL, 0, &kCFTypeArrayCallBacks);
-	key  = CFStringCreateWithCString(NULL, waitKey, kCFStringEncodingMacRoman);
+	key  = CFStringCreateWithCString(NULL, waitKey, kCFStringEncodingUTF8);
 	CFArrayAppendValue(keys, key);
 
 	if (!SCDynamicStoreSetNotificationKeys(store, keys, NULL)) {
@@ -225,7 +312,7 @@ do_wait(char *waitKey, int timeout)
 	}
 	CFRelease(key);
 
-	if (waitTimeout > 0) {
+	if (timeout > 0) {
 		signal(SIGALRM, waitTimeout);
 		bzero(&itv, sizeof(itv));
 		itv.it_value.tv_sec = timeout;
